pixelstats: Update dropdetect ratelimit to 50/day

Bug: 111400987
Test: test_client drop detect 51 times, ratelimited last time.
Change-Id: I97ede2d2b886f6a4549da15aebe4ff72ac5d844d
diff --git a/pixelstats/1.0/default/PixelStats.cpp b/pixelstats/1.0/default/PixelStats.cpp
index 2a7319d..b5d3d78 100644
--- a/pixelstats/1.0/default/PixelStats.cpp
+++ b/pixelstats/1.0/default/PixelStats.cpp
@@ -132,8 +132,8 @@
 
 Return<void> PixelStats::reportPhysicalDropDetected(int32_t confidencePctg, int32_t accelPeak,
                                                     int32_t freefallDurationMs) {
-    // Ratelimit to max 10 / 24hrs (expected 0/24hrs)
-    if (rateLimit(android::metricslogger::ACTION_PHYSICAL_DROP, 10))
+    // Ratelimit to max 50 / 24hrs (expected 0/24hrs)
+    if (rateLimit(android::metricslogger::ACTION_PHYSICAL_DROP, 50))
         return Void();
 
     logIntAction(ACTION_PHYSICAL_DROP, FIELD_CONFIDENCE_PERCENT, confidencePctg,